###############################################################################
#
#  CppExtensionCallbacks.py --
#
#  $LastChangedDate$
#  $LastChangedRevision$
#  $LastChangedBy$
#
#  Author: ltomaso
#
#  History: 
#    March 5, 2013 - initial revision
#
###############################################################################

# method called when the extension is loaded
def onInit(context):
    if context == 'DesignXplorer':
        ExtAPI.Log.WriteMessage('onInit DX')
        dlldir = System.IO.Path.Combine(ExtAPI.ExtensionMgr.CurrentExtension.InstallDir,System.IO.Path.Combine("bin",System.IO.Path.Combine("Win64","Release")))
        cppoptimizerdll = System.IO.Path.Combine(dlldir,"CppOptimizerExample.dll")

        # creates a ctypes library object
        global opt
        opt = ctypes.CDLL(cppoptimizerdll)
        opt.AddDoubleVariable.argtypes = [ctypes.c_int32,ctypes.c_double,ctypes.c_double,ctypes.c_double]
        opt.AddObjective.argtypes = [ctypes.c_int32,ctypes.c_int32,ctypes.c_double,ctypes.c_double] 
        opt.AddConstraint.argtypes = [ctypes.c_int32,ctypes.c_int32,ctypes.c_double,ctypes.c_double,ctypes.c_double]
        opt.PutNumberOfSamples.argtypes = [ctypes.c_int32]
        opt.CanRun.restype = ctypes.c_bool
        opt.RunOptimization.restype = ctypes.c_int32
        opt.PutMaximumNumberOfCandidates.argtypes = [ctypes.c_int32]
        opt.GetInputValues.argtypes = [ctypes.c_int32,ctypes.POINTER(ctypes.c_double)]
        opt.AddOutputValues.argtypes = [ctypes.c_int32,ctypes.c_bool,ctypes.POINTER(ctypes.c_double),ctypes.c_int32]
        opt.GetNumberOfGeneratedCanidatePoints.restype = ctypes.c_int32
        opt.GetCandidatePointValues.argtypes = [ctypes.c_int32,ctypes.POINTER(ctypes.c_double)]
        opt.GetCostFunctionValues.argtypes = [ctypes.POINTER(ctypes.c_double),ctypes.POINTER(ctypes.c_bool)]
        opt.GetStatus.restype = ctypes.c_wchar_p
        ExtAPI.Log.WriteMessage('onInit DX - end')

# method called when extension is unloaded
def onTerminate(context):
    if context == 'DesignXplorer':
        ExtAPI.Log.WriteMessage('onTerminate DX')
        global opt
        # cleans up by removing reference to the ctypes library object
        libHandle = opt._handle
        del opt
        # unloads the DLL
        if System.IntPtr.Size == 8:
            ctypes.windll.kernel32.FreeLibrary.argtypes = [ctypes.c_void_p]
        ctypes.windll.kernel32.FreeLibrary(libHandle)
        
